@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from __future__ import division
+from __future__ import division, print_function
 
 from collections import Iterable
 
@@ -8,7 +8,8 @@ import numpy as np
 import pandas as pd
 from fastcache import lru_cache
 from cached_property import cached_property
-from scipy.stats import spearmanr, pearsonr, morestats
+from scipy.stats import spearmanr, pearsonr
+from scipy import stats
 
 from . import performance as pef, plotting as pl
 from .prepare import (get_clean_factor_and_forward_returns, rate_of_return,
@@ -24,9 +25,11 @@ class FactorAnalyzer(object):
         ----------
         factor :
             因子值
-            pd.DataFrame
+            pd.DataFrame / pd.Series
             一个 DataFrame, index 为日期, columns 为资产,
             values 为因子的值
+            或一个 Series, index 为日期和资产的 MultiIndex,
+            values 为因子的值
         prices :
             用于计算因子远期收益的价格数据
             pd.DataFrame
@@ -60,14 +63,16 @@ class FactorAnalyzer(object):
             如果要分析分组(行业)中性的组合, 您最好设置为 True
         quantiles :
             int or sequence[float]
-            在因子分组中按照因子值大小平均分组的组数. 默认为 None
-             或分位数序列, 允许不均匀分组
+            默认为 None
+            在因子分组中按照因子值大小平均分组的组数
+            或分位数序列, 允许不均匀分组.
             例如 [0, .10, .5, .90, 1.] 或 [.05, .5, .95]
             'quantiles' 和 'bins' 有且只能有一个不为 None
         bins :
-            sequence[float]
-            在因子分组中使用的等宽 (按照因子值) 区间的数量. 默认为 None
-            或边界值序列, 允许不均匀的区间宽度
+            int or sequence[float]
+            默认为 None
+            在因子分组中使用的等宽 (按照因子值) 区间的数量
+            或边界值序列, 允许不均匀的区间宽度.
             例如 [-4, -2, -0.5, 0, 10]
             'quantiles' 和 'bins' 有且只能有一个不为 None
         periods :
@@ -202,13 +207,15 @@ class FactorAnalyzer(object):
         plot_ic_hist: 画信息比率分布直方图
         plot_ic_qq: 画信息比率 qq 图
         plot_quantile_returns_bar: 画各分位数平均收益图
+        plot_quantile_returns_violin: 画各分位数收益分布图
         plot_mean_quantile_returns_spread_time_series: 画最高分位减最低分位收益图
         plot_ic_by_group: 画按行业分组信息比率(IC)图
         plot_factor_auto_correlation: 画因子自相关图
         plot_top_bottom_quantile_turnover: 画最高最低分位换手率图
         plot_monthly_ic_heatmap: 画月度信息比率(IC)图
-        plot_cumulative_returns: 画按因子值加权多空组合每日累积收益图
-        plot_cumulative_returns_by_quantile: 画做多最高分位做空最低分位多空组合每日累计收益图
+        plot_cumulative_returns: 画按因子值加权组合每日累积收益图
+        plot_top_down_cumulative_returns: 画做多最大分位数做空最小分位数组合每日累积收益图
+        plot_cumulative_returns_by_quantile: 画各分位数每日累积收益图
         plot_quantile_average_cumulative_return: 因子预测能力平均累计收益图
         plot_events_distribution: 画有效因子数量统计图
 
@@ -223,7 +230,7 @@ class FactorAnalyzer(object):
         """
 
     def __init__(self, factor, prices, groupby=None, weights=1.0,
-                 quantiles=5, bins=None, periods=(1, 5, 10),
+                 quantiles=None, bins=None, periods=(1, 5, 10),
                  binning_by_group=False, max_loss=0.25, zero_aware=False):
 
         self.factor = factor
@@ -244,19 +251,18 @@ class FactorAnalyzer(object):
         """格式化因子数据和定价数据"""
 
         factor_data = self.factor
+        if isinstance(factor_data, pd.DataFrame):
+            factor_data = factor_data.stack(dropna=False)
 
-        stocks = list(factor_data.columns.drop_duplicates())
-        start_date = min(factor_data.index)
-        end_date = max(factor_data.index)
+        stocks = list(factor_data.index.get_level_values(1).drop_duplicates())
+        start_date = min(factor_data.index.get_level_values(0))
+        end_date = max(factor_data.index.get_level_values(0))
 
         if hasattr(self.prices, "__call__"):
             prices = self.prices(securities=stocks,
                                  start_date=start_date,
-                                 end_date=end_date).append(
-                     self.prices(securities=stocks,
                                  end_date=end_date,
-                                 count=max(self._periods) + 1)
-                    )
+                                 period=max(self._periods))
             prices = prices.loc[~prices.index.duplicated()]
         else:
             prices = self.prices
@@ -279,7 +285,7 @@ class FactorAnalyzer(object):
         self._weights = weights
 
         self._clean_factor_data = get_clean_factor_and_forward_returns(
-            factor_data.stack(),
+            factor_data,
             prices,
             groupby=groupby,
             weights=weights,
@@ -295,24 +301,47 @@ class FactorAnalyzer(object):
     def clean_factor_data(self):
         return self._clean_factor_data
 
+    @property
+    def _factor_quantile(self):
+        data = self.clean_factor_data
+        if not data.empty:
+            return max(data.factor_quantile)
+        else:
+            _quantiles = self._quantiles
+            _bins = self._bins
+            _zero_aware = self._zero_aware
+            get_len = lambda x: len(x) - 1 if isinstance(x, Iterable) else int(x)
+            if _quantiles is not None and _bins is None and not _zero_aware:
+                return get_len(_quantiles)
+            elif _quantiles is not None and _bins is None and _zero_aware:
+                return int(_quantiles) // 2 * 2
+            elif _bins is not None and _quantiles is None and not _zero_aware:
+                return get_len(_bins)
+            elif _bins is not None and _quantiles is None and _zero_aware:
+                return int(_bins) // 2 * 2
+
     @lru_cache(16)
     def calc_mean_return_by_quantile(self, by_date=False, by_group=False,
                                      demeaned=False, group_adjust=False):
-        """计算按分位数分组加权因子收益和标准差
+        """计算按分位数分组因子收益和标准差
+
+        因子收益为收益按照 weight 列中权重的加权平均值
 
         参数:
         by_date:
-        - True: 在分位数分组下, 得到每天的因子收益和标准差
-        - False: 按分位数分组加权因子收益和标准差
+        - True: 按天计算收益
+        - False: 不按天计算收益
         by_group:
-        - True: 在分位数分组下, 得到每个行业的因子收益和标准差
-        - False: 按分位数分组加权因子收益和标准差
+        - True: 按行业计算收益
+        - False: 不按行业计算收益
         demeaned:
-        - True: 对每天的因子收益和标准差去均值
-        - False: 按分位数分组加权因子收益和标准差
+        - True: 使用超额收益计算各分位数收益，超额收益=收益-基准收益
+                (基准收益被认为是每日所有股票收益按照weight列中权重的加权的均值)
+        - False: 不使用超额收益
         group_adjust:
-        - True: 每天的因子收益和标准差按行业去均值
-        - False: 按分位数分组加权因子收益和标准差
+        - True: 使用行业中性收益计算各分位数收益，行业中性收益=收益-行业收益
+                (行业收益被认为是每日各个行业股票收益按照weight列中权重的加权的均值)
+        - False: 不使用行业中性收益
         """
         return pef.mean_return_by_quantile(self._clean_factor_data,
                                            by_date=by_date,
@@ -322,15 +351,19 @@ class FactorAnalyzer(object):
 
     @lru_cache(4)
     def calc_factor_returns(self, demeaned=True, group_adjust=False):
-        """计算按因子值加权多空组合每日收益
+        """计算按因子值加权组合每日收益
+
+        权重 = 每日因子值 / 每日因子值的绝对值的和
+        正的权重代表买入, 负的权重代表卖出
 
         参数:
         demeaned:
-        - True:对每天的因子收益去均值
-        - False: 每日因子收益
+        - True: 对权重去均值 (每日权重 = 每日权重 - 每日权重的均值), 使组合转换为 cash-neutral 多空组合
+        - False: 不对权重去均值
         group_adjust:
-        - True: 对每天的因子收益去均值按行业去均值
-        - False: 计算按因子值加权多空组合每日收益
+        - True: 对权重分行业去均值 (每日权重 = 每日权重 - 每日各行业权重的均值)，
+                使组合转换为 industry-neutral 多空组合
+        - False: 不对权重分行业去均值
         """
         return pef.factor_returns(self._clean_factor_data,
                                   demeaned=demeaned,
@@ -345,22 +378,24 @@ class FactorAnalyzer(object):
         upper_quant: 用 upper_quant 选择的分位数减去 lower_quant 选择的分位数
         lower_quant: 用 upper_quant 选择的分位数减去 lower_quant 选择的分位数
         by_date:
-        - True: 每天的两个分位数相减的因子收益和标准差
-        - False: 两个分位数相减的因子收益和标准差
+        - True: 按天计算两个分位数相减的因子收益和标准差
+        - False: 不按天计算两个分位数相减的因子收益和标准差
         by_group:
-        - True: 每个行业的两个分位数相减的因子收益和标准差
-        - False: 两个分位数相减的因子收益和标准差
+        - True: 分行业计算两个分位数相减的因子收益和标准差
+        - False: 不分行业计算两个分位数相减的因子收益和标准差
         demeaned:
-        - True: 两个分位数相减去均值后的每天的因子收益和标准差
-        - False: 两个分位数相减的因子收益和标准差
+        - True: 使用超额收益 (基准收益被认为是每日所有股票收益按照weight列中权重加权的均值)
+        - False: 不使用超额收益
         group_adjust:
-        - True: 两个分位数相减按行业去均值后的因子收益和标准差
-        - False: 两个分位数相减的因子收益和标准差
+        - True: 使用行业中性收益 (行业收益被认为是每日各个行业股票收益按照weight列中权重加权的均值)
+        - False: 不使用行业中性收益
         """
-        upper_quant = upper_quant if upper_quant is not None else self._quantiles
+        upper_quant = upper_quant if upper_quant is not None else self._factor_quantile
         lower_quant = lower_quant if lower_quant is not None else 1
-        if not 1 <= upper_quant <= self._quantiles or not 1 <= lower_quant <= self._quantiles:
-            raise ValueError("upper_quant 和 low_quant 的取值范围为 1 - %s 的整数" % self._quantiles)
+        if ((not 1 <= upper_quant <= self._factor_quantile) or
+            (not 1 <= lower_quant <= self._factor_quantile)):
+            raise ValueError("upper_quant 和 low_quant 的取值范围为 1 - %s 的整数"
+                             % self._factor_quantile)
         mean, std = self.calc_mean_return_by_quantile(by_date=by_date, by_group=by_group,
                                                       demeaned=demeaned, group_adjust=group_adjust,)
         mean = mean.apply(rate_of_return, axis=0)
@@ -374,13 +409,23 @@ class FactorAnalyzer(object):
     def calc_factor_alpha_beta(self, demeaned=True, group_adjust=False):
         """计算因子的 alpha 和 beta
 
+        因子值加权组合每日收益 = beta * 市场组合每日收益 + alpha
+
+        因子值加权组合每日收益计算方法见 calc_factor_returns 函数
+        市场组合每日收益是每日所有股票收益按照weight列中权重加权的均值
+        结果中的 alpha 是年化 alpha
+
         参数:
         demeaned:
-        - True:去均值后的因子收益计算得到的alpha和beta
-        - False: 计算因子的 alpha 和 beta
+        详见 calc_factor_returns 中 demeaned 参数
+        - True: 对因子值加权组合每日收益的权重去均值 (每日权重 = 每日权重 - 每日权重的均值),
+                使组合转换为cash-neutral多空组合
+        - False: 不对权重去均值
         group_adjust:
-        - True: 按行业去均值后的因子收益计算得到的alpha和beta
-        - False: 计算因子的 alpha 和 beta
+        详见 calc_factor_returns 中 group_adjust 参数
+        - True: 对权重分行业去均值 (每日权重 = 每日权重 - 每日各行业权重的均值)，
+                使组合转换为 industry-neutral 多空组合
+        - False: 不对权重分行业去均值
         """
         return pef.factor_alpha_beta(self._clean_factor_data,
                                      demeaned=demeaned,
@@ -392,11 +437,11 @@ class FactorAnalyzer(object):
 
         参数:
         group_adjust:
-        - True: 按行业去均值后的因子收益计算得到的IC值
-        - False: IC值
+        - True: 使用行业中性收益计算 IC (行业收益被认为是每日各个行业股票收益按照weight列中权重加权的均值)
+        - False: 不使用行业中性收益
         by_group:
-        - True: 得到每日因子信息比率的各行业IC值
-        - False: IC值
+        - True: 分行业计算 IC
+        - False: 不分行业计算 IC
         method:
         - 'rank': 用秩相关系数计算IC值
         - 'normal': 用普通相关系数计算IC值
@@ -422,11 +467,11 @@ class FactorAnalyzer(object):
 
         参数:
         group_adjust:
-        - True: 按行业去均值后的因子收益计算得到的IC值均值
-        - False: IC值均值
+        - True: 使用行业中性收益计算 IC (行业收益被认为是每日各个行业股票收益按照weight列中权重加权的均值)
+        - False: 不使用行业中性收益
         by_group:
-        - True: 各行业IC值均值
-        - False: IC值均值
+        - True: 分行业计算 IC
+        - False: 不分行业计算 IC
         by_time:
         - 'Y': 按年求均值
         - 'M': 按月求均值
@@ -460,8 +505,13 @@ class FactorAnalyzer(object):
         参数:
         periods_before: 计算过去的天数
         periods_after: 计算未来的天数
-        demeaned: 对每日因子收益去均值后计算未来和过去的收益均值和标准差
-        group_adjust: 按行业对因子收益去均值后计算未来和过去的收益均值和标准差
+        demeaned:
+        - True: 使用超额收益计算累积收益 (基准收益被认为是每日所有股票收益按照weight列中权重加权的均值)
+        - False: 不使用超额收益
+        group_adjust:
+        - True: 使用行业中性化后的收益计算累积收益
+                (行业收益被认为是每日各个行业股票收益按照weight列中权重加权的均值)
+        - False: 不使用行业中性化后的收益
         """
         return pef.average_cumulative_return_by_quantile(
             self._clean_factor_data,
@@ -476,6 +526,8 @@ class FactorAnalyzer(object):
     def calc_autocorrelation(self, rank=True):
         """根据调仓周期确定滞后期的每天计算因子自相关性
 
+        当日因子值和滞后period天的因子值的自相关性
+
         参数:
         rank:
         - True: 秩相关系数
@@ -493,7 +545,7 @@ class FactorAnalyzer(object):
 
     @lru_cache(None)
     def calc_quantile_turnover_mean_n_days_lag(self, n=10):
-        """各分位数 1 - n 天换手率的平均
+        """各分位数滞后1天到n天的换手率均值
 
         参数:
         n: 滞后 1 天到 n 天的换手率
@@ -514,10 +566,10 @@ class FactorAnalyzer(object):
 
     @lru_cache(None)
     def calc_autocorrelation_n_days_lag(self, n=10, rank=False):
-        """滞后n天因子值自相关性
+        """滞后1-n天因子值自相关性
 
         参数:
-        n: 滞后 1 天到 n 天的因子值自相关性
+        n: 滞后1天到n天的因子值自相关性
         rank:
         - True: 秩相关系数
         - False: 普通相关系数
@@ -556,16 +608,18 @@ class FactorAnalyzer(object):
         return ac.mean(level=('group' if by_group else None))
 
     def calc_ic_mean_n_days_lag(self, n=10, group_adjust=False, by_group=False, method=None):
-        """滞后 0 - n 天因子收益信息比率(IC)的移动平均
+        """滞后 0 - n 天因子收益信息比率(IC)的均值
+
+        滞后 n 天 IC 表示使用当日因子值和滞后 n 天的因子收益计算 IC
 
         参数:
-        n: 滞后0-n天因子收益的信息比率(IC)的移动平均
+        n: 滞后0-n天因子收益的信息比率(IC)的均值
         group_adjust:
-        - True: 按行业对因子收益去均值后滞后0-n天因子收益的信息比率(IC)的移动平均
-        - False: 滞后 0 - n 天因子收益信息比率(IC)的移动平均
+        - True: 使用行业中性收益计算 IC (行业收益被认为是每日各个行业股票收益按照weight列中权重加权的均值)
+        - False: 不使用行业中性收益
         by_group:
-        - True: 滞后 0 - n 天各行业的因子收益信息比率(IC)的移动平均
-        - False: 滞后 0 - n 天因子收益信息比率(IC)的移动平均
+        - True: 分行业计算 IC
+        - False: 不分行业计算 IC
         method:
         - 'rank': 用秩相关系数计算IC值
         - 'normal': 用普通相关系数计算IC值
@@ -656,7 +710,7 @@ class FactorAnalyzer(object):
         """分行业的分位数收益
 
         返回值:
-            Multi_index 的 DataFrame
+            MultiIndex 的 DataFrame
             index 分别是分位数、 行业名称,  column 是 period  (1, 5, 10)
         """
         mean_return_group, _ = self.calc_mean_return_by_quantile(
@@ -695,6 +749,15 @@ class FactorAnalyzer(object):
 
         参数:
         period: 指定调仓周期
+        demeaned:
+        详见 calc_mean_return_by_quantile 中 demeaned 参数
+        - True: 使用超额收益计算累积收益 (基准收益被认为是每日所有股票收益按照weight列中权重加权的均值)
+        - False: 不使用超额收益
+        group_adjust:
+        详见 calc_mean_return_by_quantile 中 group_adjust 参数
+        - True: 使用行业中性化后的收益计算累积收益
+                (行业收益被认为是每日各个行业股票收益按照weight列中权重加权的均值)
+        - False: 不使用行业中性化后的收益
         """
         if period is None:
             period = self._periods[0]
@@ -711,16 +774,25 @@ class FactorAnalyzer(object):
     @lru_cache(20)
     def calc_cumulative_returns(self, period=None,
                                 demeaned=False, group_adjust=False):
-        """计算指定调仓周期的按因子值加权多空组合每日累积收益
+        """计算指定调仓周期的按因子值加权组合每日累积收益
+
+        当 period > 1 时，组合的累积收益计算方法为：
+        组合每日收益 = （从第0天开始每period天一调仓的组合每日收益 +
+                        从第1天开始每period天一调仓的组合每日收益 + ... +
+                        从第period-1天开始每period天一调仓的组合每日收益) / period
+        组合累积收益 = 组合每日收益的累积
 
         参数:
         period: 指定调仓周期
         demeaned:
-        - True: 对每日因子收益去均值后按因子值加权多空组合每日累积收益
-        - False: 按因子值加权多空组合每日累积收益
+        详见 calc_factor_returns 中 demeaned 参数
+        - True: 对权重去均值 (每日权重 = 每日权重 - 每日权重的均值), 使组合转换为 cash-neutral 多空组合
+        - False: 不对权重去均值
         group_adjust:
-        - True: 按行业对因子收益去均值后按因子值加权多空组合每日累积收益
-        - False: 按因子值加权多空组合每日累积收益
+        详见 calc_factor_returns 中 group_adjust 参数
+        - True: 对权重分行业去均值 (每日权重 = 每日权重 - 每日各行业权重的均值)，
+                使组合转换为 industry-neutral 多空组合
+        - False: 不对权重分行业去均值
         """
         if period is None:
             period = self._periods[0]
@@ -734,16 +806,19 @@ class FactorAnalyzer(object):
     @lru_cache(20)
     def calc_top_down_cumulative_returns(self, period=None,
                                          demeaned=False, group_adjust=False):
-        """计算指定调仓周期和前面定义好的加权方式计算多空组合每日累计收益
+        """计算做多最大分位，做空最小分位组合每日累积收益
 
         参数:
         period: 指定调仓周期
-        emeaned:
-        - True: 对每日因子收益去均值后按因子值加权多空组合每日累积收益
-        - False: 按因子值加权多空组合每日累积收益
+        demeaned:
+        详见 calc_mean_return_by_quantile 中 demeaned 参数
+        - True: 使用超额收益计算累积收益 (基准收益被认为是每日所有股票收益按照weight列中权重加权的均值)
+        - False: 不使用超额收益
         group_adjust:
-        - True: 按行业对因子收益去均值后按因子值加权多空组合每日累积收益
-        - False: 按因子值加权多空组合每日累积收益
+        详见 calc_mean_return_by_quantile 中 group_adjust 参数
+        - True: 使用行业中性化后的收益计算累积收益
+                (行业收益被认为是每日各个行业股票收益按照weight列中权重加权的均值)
+        - False: 不使用行业中性化后的收益
         """
         if period is None:
             period = self._periods[0]
@@ -754,7 +829,7 @@ class FactorAnalyzer(object):
         )
         mean_returns = mean_returns.apply(rate_of_return, axis=0)
 
-        upper_quant = mean_returns[period_col].xs(self._quantiles,
+        upper_quant = mean_returns[period_col].xs(self._factor_quantile,
                                                   level='factor_quantile')
         lower_quant = mean_returns[period_col].xs(1,
                                                   level='factor_quantile')
@@ -829,11 +904,11 @@ class FactorAnalyzer(object):
 
         参数:
         demeaned:
-        - True: 对每日因子收益去均值求得因子收益表
-        - False: 因子收益表
+        - True: 使用超额收益计算 (基准收益被认为是每日所有股票收益按照weight列中权重的加权的均值)
+        - False: 不使用超额收益
         group_adjust:
-        - True: 按行业对因子收益去均值后求得因子收益表
-        - False: 因子收益表
+        - True: 使用行业中性收益 (行业收益被认为是每日各个行业股票收益按照weight列中权重的加权的均值)
+        - False: 不使用行业中性收益
         """
         mean_return_by_quantile = self.calc_mean_return_by_quantile(
             by_date=False, by_group=False,
@@ -841,7 +916,7 @@ class FactorAnalyzer(object):
         )[0].apply(rate_of_return, axis=0)
 
         mean_returns_spread, _ = self.compute_mean_returns_spread(
-            upper_quant=self._quantiles,
+            upper_quant=self._factor_quantile,
             lower_quant=1,
             by_date=True,
             by_group=False,
@@ -863,7 +938,16 @@ class FactorAnalyzer(object):
         )
 
     def plot_information_table(self, group_adjust=False, method=None):
-        """打印信息比率 (IC)相关表"""
+        """打印信息比率 (IC)相关表
+
+        参数:
+        group_adjust:
+        - True：使用行业中性收益 (行业收益被认为是每日各个行业股票收益按照weight列中权重的加权的均值)
+        - False：不使用行业中性收益
+        method：
+        - 'rank'：用秩相关系数计算IC值
+        - 'normal':用相关系数计算IC值
+        """
         ic = self.calc_factor_information_coefficient(
             group_adjust=group_adjust,
             by_group=False,
@@ -880,8 +964,8 @@ class FactorAnalyzer(object):
 
         参数:
         group_adjust:
-        - True: 按行业对因子收益去均值后求得因子收益用于计算IC
-        - False: 因子收益用于计算IC
+        - True: 使用行业中性收益 (行业收益被认为是每日各个行业股票收益按照weight列中权重的加权的均值)
+        - False: 不使用行业中性收益
         method:
         - 'rank': 用秩相关系数计算IC值
         - 'normal':用相关系数计算IC值
@@ -896,8 +980,8 @@ class FactorAnalyzer(object):
 
         参数:
         group_adjust:
-        - True: 按行业对因子收益去均值后求得因子收益用于计算IC
-        - False: 因子收益用于计算IC
+        - True: 使用行业中性收益 (行业收益被认为是每日各个行业股票收益按照weight列中权重的加权的均值)
+        - False: 不使用行业中性收益
         method:
         - 'rank': 用秩相关系数计算IC值
         - 'normal': 用相关系数计算IC值
@@ -914,8 +998,8 @@ class FactorAnalyzer(object):
 
         参数:
         group_adjust:
-        - True: 按行业对因子收益去均值后求得因子收益用于计算IC
-        - False: 因子收益用于计算IC
+        - True: 使用行业中性收益 (行业收益被认为是每日各个行业股票收益按照weight列中权重的加权的均值)
+        - False: 不使用行业中性收益
         method:
         - 'rank': 用秩相关系数计算IC值
         - 'normal': 用相关系数计算IC值
@@ -924,7 +1008,7 @@ class FactorAnalyzer(object):
         - 't': t 分布
         """
         theoretical_dist = 'norm' if theoretical_dist is None else theoretical_dist
-        theoretical_dist = morestats._parse_dist_kw(theoretical_dist)
+        theoretical_dist = getattr(stats, theoretical_dist)
         ic = self.calc_factor_information_coefficient(
             group_adjust=group_adjust,
             by_group=False,
@@ -941,11 +1025,12 @@ class FactorAnalyzer(object):
         - True: 各行业的各分位数平均收益图
         - False: 各分位数平均收益图
         demeaned:
-        - True: 对每日因子收益去均值后的各分位数平均收益图
-        - False: 各分位数平均收益图
+        - True: 使用超额收益计算累积收益 (基准收益被认为是每日所有股票收益按照weight列中权重加权的均值)
+        - False: 不使用超额收益
         group_adjust:
-        - True: 按行业对因子收益去均值后的各分位数平均收益图
-        - False: 各分位数平均收益图
+        - True: 使用行业中性化后的收益计算累积收益
+                (行业收益被认为是每日各个行业股票收益按照weight列中权重加权的均值)
+        - False: 不使用行业中性化后的收益
         """
         mean_return_by_quantile = self.calc_mean_return_by_quantile(
             by_date=False, by_group=by_group,
@@ -958,7 +1043,19 @@ class FactorAnalyzer(object):
 
     def plot_quantile_returns_violin(self, demeaned=False, group_adjust=False,
                                      ylim_percentiles=(1, 99)):
-        """"""
+        """画各分位数收益分布图
+
+        参数:
+        demeaned:
+        - True: 使用超额收益计算累积收益 (基准收益被认为是每日所有股票收益按照weight列中权重加权的均值)
+        - False: 不使用超额收益
+        group_adjust:
+        - True: 使用行业中性化后的收益计算累积收益
+                (行业收益被认为是每日各个行业股票收益按照weight列中权重加权的均值)
+        - False: 不使用行业中性化后的收益
+        plot_quantile_returns_violin: 有效收益分位数(单位为百分之). 画图时y轴的范围为有效收益的最大/最小值.
+                                      例如 (1, 99) 代表收益的从小到大排列的 1% 分位到 99% 分位为有效收益.
+        """
         mean_return_by_date = self.calc_mean_return_by_quantile(
             by_date=True, by_group=False,
             demeaned=demeaned, group_adjust=group_adjust
@@ -974,15 +1071,16 @@ class FactorAnalyzer(object):
 
         参数:
         demeaned:
-        - True: 对每日因子收益去均值后的最高分位减最低分位收益图
-        - False: 最高分位减最低分位收益图
+        - True: 使用超额收益计算累积收益 (基准收益被认为是每日所有股票收益按照weight列中权重加权的均值)
+        - False: 不使用超额收益
         group_adjust:
-        - True: 按行业对因子收益去均值后的最高分位减最低分位收益图图
-        - False: 最高分位减最低分位收益图
+        - True: 使用行业中性化后的收益计算累积收益
+                (行业收益被认为是每日各个行业股票收益按照weight列中权重加权的均值)
+        - False: 不使用行业中性化后的收益
         bandwidth: n, 加减 n 倍当日标准差
         """
         mean_returns_spread, mean_returns_spread_std = self.compute_mean_returns_spread(
-            upper_quant=self._quantiles,
+            upper_quant=self._factor_quantile,
             lower_quant=1,
             by_date=True,
             by_group=False,
@@ -1000,8 +1098,8 @@ class FactorAnalyzer(object):
 
         参数:
         group_adjust:
-        - True: 按行业对因子收益去均值后的行业分组信息比率图
-        - False: 行业分组信息比率图
+        - True: 使用行业中性收益 (行业收益被认为是每日各个行业股票收益按照weight列中权重的加权的均值)
+        - False: 不使用行业中性收益
         method:
         - 'rank': 用秩相关系数计算IC值
         - 'normal': 用相关系数计算IC值
@@ -1017,7 +1115,7 @@ class FactorAnalyzer(object):
         """画因子自相关图
 
         参数:
-        periods: 调仓周期
+        periods: 滞后周期
         rank:
         - True: 用秩相关系数
         - False: 用相关系数
@@ -1061,8 +1159,8 @@ class FactorAnalyzer(object):
 
         参数:
         group_adjust:
-        - True: 按行业对因子收益去均值后的月度信息比率图
-        - False: 月度信息比率图
+        - True: 使用行业中性收益 (行业收益被认为是每日各个行业股票收益按照weight列中权重的加权的均值)
+        - False: 不使用行业中性收益
         """
         ic_monthly = self.calc_mean_information_coefficient(
             group_adjust=group_adjust, by_group=False, by_time="M"
@@ -1071,16 +1169,20 @@ class FactorAnalyzer(object):
 
     def plot_cumulative_returns(self, period=None, demeaned=False,
                                 group_adjust=False):
-        """画按因子值加权多空组合每日累积收益图
+        """画按因子值加权组合每日累积收益图
 
         参数:
         periods: 调仓周期
         demeaned:
-        - True: 对每日因子收益去均值后的按因子值加权多空组合每日累积收益图
-        - False: 按因子值加权多空组合每日累积收益图
+        详见 calc_factor_returns 中 demeaned 参数
+        - True: 对因子值加权组合每日收益的权重去均值 (每日权重 = 每日权重 - 每日权重的均值),
+                使组合转换为cash-neutral多空组合
+        - False: 不对权重去均值
         group_adjust:
-        - True: 按行业对因子收益去均值后的按因子值加权多空组合每日累积收益图
-        - False: 按因子值加权多空组合每日累积收益图
+        详见 calc_factor_returns 中 group_adjust 参数
+        - True: 对权重分行业去均值 (每日权重 = 每日权重 - 每日各行业权重的均值)，
+                使组合转换为 industry-neutral 多空组合
+        - False: 不对权重分行业去均值
         """
         if period is None:
             period = self._periods
@@ -1096,18 +1198,49 @@ class FactorAnalyzer(object):
                     period=p
                 )
 
+    def plot_top_down_cumulative_returns(self, period=None, demeaned=False, group_adjust=False):
+        """画做多最大分位数做空最小分位数组合每日累积收益图
+
+        period: 指定调仓周期
+        demeaned:
+        详见 calc_mean_return_by_quantile 中 demeaned 参数
+        - True: 使用超额收益计算累积收益 (基准收益被认为是每日所有股票收益按照weight列中权重加权的均值)
+        - False: 不使用超额收益
+        group_adjust:
+        详见 calc_mean_return_by_quantile 中 group_adjust 参数
+        - True: 使用行业中性化后的收益计算累积收益
+                (行业收益被认为是每日各个行业股票收益按照weight列中权重加权的均值)
+        - False: 不使用行业中性化后的收益
+        """
+        if period is None:
+            period = self._periods
+        if not isinstance(period, Iterable):
+            period = (period, )
+        period = tuple(period)
+        for p in period:
+            if p in self._periods:
+                factor_return = self.calc_top_down_cumulative_returns(
+                    period=p, demeaned=demeaned, group_adjust=group_adjust,
+                )
+                pl.plot_top_down_cumulative_returns(
+                    factor_return, period=p
+                )
+
     def plot_cumulative_returns_by_quantile(self, period=None, demeaned=False,
                                             group_adjust=False):
-        """画做多最高分位做空最低分位多空组合每日累计收益图
+        """画各分位数每日累积收益图
 
         参数:
-        periods: 调仓周期
+        period: 调仓周期
         demeaned:
-        - True: 对每日因子收益去均值后的多空组合每日累计收益图
-        - False: 多空组合每日累计收益图
+        详见 calc_mean_return_by_quantile 中 demeaned 参数
+        - True: 使用超额收益计算累积收益 (基准收益被认为是每日所有股票收益按照weight列中权重加权的均值)
+        - False: 不使用超额收益
         group_adjust:
-        - True: 按行业对因子收益去均值后的多空组合每日累计收益图
-        - False: 多空组合每日累计收益图
+        详见 calc_mean_return_by_quantile 中 group_adjust 参数
+        - True: 使用行业中性化后的收益计算累积收益
+                (行业收益被认为是每日各个行业股票收益按照weight列中权重加权的均值)
+        - False: 不使用行业中性化后的收益
         """
         if period is None:
             period = self._periods
@@ -1132,28 +1265,29 @@ class FactorAnalyzer(object):
         参数:
         periods_before: 计算过去的天数
         periods_after: 计算未来的天数
-        by_quantile:
-        - True: 各分位数分别显示因子预测能力平均累计收益图
-        - False: 因子预测能力平均累计收益图
+        by_quantile: 是否各分位数分别显示因子预测能力平均累计收益图
         std_bar:
         - True: 显示标准差
         - False: 不显示标准差
         demeaned:
-        - True: 对每天的因子收益和标准差去均值
-        - False: 按分位数分组加权因子收益和标准差
+        详见 calc_mean_return_by_quantile 中 demeaned 参数
+        - True: 使用超额收益计算累积收益 (基准收益被认为是每日所有股票收益按照weight列中权重加权的均值)
+        - False: 不使用超额收益
         group_adjust:
-        - True: 每天的因子收益和标准差按行业去均值
-        - False: 按分位数分组加权因子收益和标准差
+        详见 calc_mean_return_by_quantile 中 group_adjust 参数
+        - True: 使用行业中性化后的收益计算累积收益
+                (行业收益被认为是每日各个行业股票收益按照weight列中权重加权的均值)
+        - False: 不使用行业中性化后的收益
         """
         average_cumulative_return_by_q = self.calc_average_cumulative_return_by_quantile(
             periods_before=periods_before, periods_after=periods_after,
             demeaned=demeaned, group_adjust=group_adjust
         )
         pl.plot_quantile_average_cumulative_return(average_cumulative_return_by_q,
-                                                          by_quantile=by_quantile,
-                                                          std_bar=std_bar,
-                                                          periods_before=periods_before,
-                                                          periods_after=periods_after)
+                                                   by_quantile=by_quantile,
+                                                   std_bar=std_bar,
+                                                   periods_before=periods_before,
+                                                   periods_after=periods_after)
 
     def plot_events_distribution(self, num_days=5):
         """画有效因子数量统计图
@@ -1164,7 +1298,7 @@ class FactorAnalyzer(object):
         pl.plot_events_distribution(
             events=self._clean_factor_data['factor'],
             num_days=num_days,
-            full_dates=pd.to_datetime(self.factor.index.unique())
+            full_dates=pd.to_datetime(self.factor.index.get_level_values('date').unique())
         )
 
     def create_summary_tear_sheet(self, demeaned=False, group_adjust=False):
@@ -1186,15 +1320,17 @@ class FactorAnalyzer(object):
         self.plot_turnover_table()
 
     def create_returns_tear_sheet(self, demeaned=False, group_adjust=False, by_group=False):
-        """因子收益分析
+        """因子值特征分析
 
         参数:
         demeaned:
-        - True: 对每日因子收益去均值求得因子收益表
-        - False: 因子收益表
+        详见 calc_mean_return_by_quantile 中 demeaned 参数
+        - True: 使用超额收益计算 (基准收益被认为是每日所有股票收益按照weight列中权重加权的均值)
+        - False: 不使用超额收益
         group_adjust:
-        - True: 按行业对因子收益去均值后求得因子收益表
-        - False: 因子收益表
+        详见 calc_mean_return_by_quantile 中 group_adjust 参数
+        - True: 使用行业中性化后的收益计算 (行业收益被认为是每日各个行业股票收益按照weight列中权重加权的均值)
+        - False: 不使用行业中性化后的收益
         by_group:
         - True: 画各行业的各分位数平均收益图
         - False: 不画各行业的各分位数平均收益图
@@ -1211,6 +1347,10 @@ class FactorAnalyzer(object):
         self.plot_cumulative_returns_by_quantile(period=None,
                                                  demeaned=demeaned,
                                                  group_adjust=group_adjust)
+        self.plot_top_down_cumulative_returns(period=None,
+                                              demeaned=demeaned,
+                                              group_adjust=group_adjust)
+        pl.plt.show()
         self.plot_mean_quantile_returns_spread_time_series(
             demeaned=demeaned, group_adjust=group_adjust
         )
@@ -1230,8 +1370,8 @@ class FactorAnalyzer(object):
 
         参数:
         group_adjust:
-        - True: 按行业对因子收益去均值后求得因子收益表
-        - False: 因子收益表
+        - True: 使用行业中性收益 (行业收益被认为是每日各个行业股票收益按照weight列中权重的加权的均值)
+        - False: 不使用行业中性收益
         by_group:
         - True: 画按行业分组信息比率(IC)图
         - False: 画月度信息比率(IC)图
@@ -1267,11 +1407,14 @@ class FactorAnalyzer(object):
         avgretplot: tuple 因子预测的天数
         -(计算过去的天数, 计算未来的天数)
         demeaned:
-        - True: 对每天的因子收益和标准差去均值
-        - False: 按分位数分组加权因子收益和标准差
+        详见 calc_mean_return_by_quantile 中 demeaned 参数
+        - True: 使用超额收益计算累积收益 (基准收益被认为是每日所有股票收益按照weight列中权重加权的均值)
+        - False: 不使用超额收益
         group_adjust:
-        - True: 每天的因子收益和标准差按行业去均值
-        - False: 按分位数分组加权因子收益和标准差
+        详见 calc_mean_return_by_quantile 中 group_adjust 参数
+        - True: 使用行业中性化后的收益计算累积收益
+                (行业收益被认为是每日各个行业股票收益按照weight列中权重加权的均值)
+        - False: 不使用行业中性化后的收益
         std_bar:
         - True: 显示标准差
         - False: 不显示标准差
@@ -1297,11 +1440,12 @@ class FactorAnalyzer(object):
 
         参数:
         demeaned:
-        - True: 对每天的因子收益和标准差去均值
-        - False: 按分位数分组加权因子收益和标准差
+        - True：使用超额收益计算 (基准收益被认为是每日所有股票收益按照weight列中权重加权的均值)
+        - False：不使用超额收益
         group_adjust:
-        - True: 每天的因子收益和标准差按行业去均值
-        - False: 按分位数分组加权因子收益和标准差
+        - True：使用行业中性化后的收益计算
+                (行业收益被认为是每日各个行业股票收益按照weight列中权重加权的均值)
+        - False：不使用行业中性化后的收益
         by_group:
         - True: 按行业展示
         - False: 不按行业展示
@@ -1321,6 +1465,10 @@ class FactorAnalyzer(object):
         pl.plt.show()
         self.plot_cumulative_returns(period=None, demeaned=demeaned, group_adjust=group_adjust)
         pl.plt.show()
+        self.plot_top_down_cumulative_returns(period=None,
+                                              demeaned=demeaned,
+                                              group_adjust=group_adjust)
+        pl.plt.show()
         self.plot_cumulative_returns_by_quantile(period=None,
                                                  demeaned=demeaned,
                                                  group_adjust=group_adjust)
