@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 
-from __future__ import division
+from __future__ import division, print_function
 
 import pandas as pd
 import numpy as np
@@ -14,10 +14,9 @@ import seaborn as sns
 
 from .compat import rolling_mean
 from .plot_utils import (
-    print_table, customize,
-    ICTS, ICHIST, ICQQ, QRETURNBAR, QRETURNVIOLIN, QRETURNTS, ICGROUP,
-    AUTOCORR, TBTURNOVER, ICHEATMAP, CUMRET, CUMRETQ, AVGCUMRET, EVENTSDIST,
-    MISSIINGEVENTSDIST
+    print_table, customize, ICTS, ICHIST, ICQQ, QRETURNBAR, QRETURNVIOLIN,
+    QRETURNTS, ICGROUP, AUTOCORR, TBTURNOVER, ICHEATMAP, CUMRET, TDCUMRET,
+    CUMRETQ, AVGCUMRET, EVENTSDIST, MISSIINGEVENTSDIST
 )
 from .performance import cumulative_returns
 from .utils import (ignore_warning, convert_to_forward_returns_columns)
@@ -317,7 +316,7 @@ def plot_quantile_returns_violin(return_by_q, ylim_percentiles=None, ax=None):
     unstacked_dr = (return_by_q.multiply(DECIMAL_TO_BPS))
     unstacked_dr.columns = unstacked_dr.columns.astype(str).str.replace(
         'period_', ''
-    ).set_names('forward_periods')
+    ).astype(int).set_names(QRETURNVIOLIN.get("LEGENDNAME"))
     unstacked_dr = unstacked_dr.stack()
     unstacked_dr.name = 'return'
     unstacked_dr = unstacked_dr.reset_index()
@@ -325,7 +324,7 @@ def plot_quantile_returns_violin(return_by_q, ylim_percentiles=None, ax=None):
     sns.violinplot(
         data=unstacked_dr,
         x='factor_quantile',
-        hue='forward_periods',
+        hue=QRETURNVIOLIN.get("LEGENDNAME"),
         y='return',
         orient='v',
         cut=0,
@@ -477,7 +476,7 @@ def plot_top_bottom_quantile_turnover(quantile_turnover, period=1, ax=None):
         title=TBTURNOVER.get("TITLE").format(period), ax=ax, alpha=0.6, lw=0.8
     )
 
-    ax.set(ylabel='Proportion Of Names New To Quantile', xlabel="")
+    ax.set(ylabel=TBTURNOVER.get("YLABEL"), xlabel="")
 
     return ax
 
@@ -513,7 +512,7 @@ def plot_monthly_ic_heatmap(mean_monthly_ic, ax=None):
             annot=True,
             alpha=1.0,
             center=0.0,
-            annot_kws={"size": 7},
+            annot_kws={"size": 15},
             linewidths=0.01,
             linecolor='white',
             cmap=cm.RdYlGn,
@@ -551,6 +550,25 @@ def plot_cumulative_returns(factor_returns, period=1, overlap=True, ax=None):
     return ax
 
 
+@customize
+def plot_top_down_cumulative_returns(factor_returns, period=1, ax=None):
+
+    if ax is None:
+        f, ax = plt.subplots(1, 1, figsize=(18, 6))
+
+    factor_returns.plot(ax=ax, lw=3, color='forestgreen', alpha=0.6)
+
+    ax.set(
+        ylabel=TDCUMRET.get("YLABEL"),
+        title=TDCUMRET.get("TITLE").format(period),
+        xlabel=""
+    )
+
+    ax.axhline(1.0, linestyle='-', color='black', lw=1)
+
+    return ax
+
+
 @customize
 def plot_cumulative_returns_by_quantile(
     quantile_returns, period=1, overlap=True, ax=None
@@ -574,10 +592,10 @@ def plot_cumulative_returns_by_quantile(
         ylabel=CUMRETQ.get("YLABEL"),
         title=CUMRETQ.get("TITLE").format(period),
         xlabel='',
-        yscale='symlog',
-        yticks=np.linspace(ymin, ymax, 5),
         ylim=(ymin, ymax)
     )
+    ax.set_yscale('symlog', linthresh=1)
+    ax.set_yticks(np.linspace(ymin, ymax, 8))
     ax.yaxis.set_major_formatter(ScalarFormatter())
     ax.axhline(1.0, linestyle='-', color='black', lw=1)
 
